pub struct NonPartneredLtlDataInput {
    pub carrier_name: String,
    pub pro_number: String,
}
NonPartneredLtlDataInput : Information that you provide to Amazon about a Less Than Truckload/Full Truckload (LTL/FTL) shipment by a carrier that has not partnered with Amazon.

Fields

carrier_name: String

The carrier that you are using for the inbound shipment.

pro_number: String

The PRO number ("progressive number" or "progressive ID") assigned to the shipment by the carrier.

Implementations

Information that you provide to Amazon about a Less Than Truckload/Full Truckload (LTL/FTL) shipment by a carrier that has not partnered with Amazon.